#!/bin/python

import sys

from nvexpo import nvexpo


def main() -> int:
    args = sys.argv
    if len(args) <= 1:
        nvexpo.help()
        return 0
    if len(args) == 2 and args[1] in ["--load"]:
        nvexpo.load()
        return 0

    if args[1] in ["--unset"]:
        nvexpo.unset_env(args[2:])
        return 0

    if args[1] in ["init"]:
        try:
            nvexpo.init(args[2])
        except IndexError:
            nvexpo.init()
        return 0

    raw_vars = args[1:]
    if not all("=" in x for x in raw_vars):
        nvexpo.help()
        return 1

    variables = {}
    for raw_var in raw_vars:
        try:
            key, value = raw_var.split("=", 1)
        except ValueError:
            nvexpo.help()
            return 1
        key = key.strip("=")
        value = value.strip("=").strip("\"")
        variables[key] = value
        if not key or not value:
            nvexpo.help()
            return 1
    nvexpo.set_env(variables)
    return 0


if __name__ == "__main__":
    sys.exit(main())
